yakumo.keystone.v3.user

Package yakumo :: Package keystone :: Package v3 :: Module user |
[hide private]
[frames] | no frames]

# Module user

source code

Resource class and its manager for users in Identity V3 API

Classes | [hide private]
| Resource resource class for users on Identity V3 API
| Manager manager class for users on Identity V3 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.keystone.v3``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('password'
      , 'password', mapper.Noop), ('email', 'email', mapper.Noop), ('project
      ', 'default_project_id', mapper.Resource('keystone.project')), ('domai
      n', 'domain_id', mapper.Resource('keystone.domain')), ('is_enabled', '
      enabled', mapper.Noop),]